import cv2


class VideoIncrustation(object):
    def __init__(self, box=[0, 575, 720, 575 + 1280]):
        self.box = box

    def build(self, *args, **kwargs):
        pass

    def incrust_image(self, big_image, image):
        y1, x1, y2, x2 = self.box
        box_height, box_width = y2 - y1, x2 - x1
        im_height, im_width = image.shape[:2]
        if im_height != box_height or im_width != box_width:
            image = cv2.resize(image, (box_width, box_height))
        big_image[y1:y2, x1:x2, :] = image

    def refresh(self, big_image, image):
        self.incrust_image(big_image, image)



import cv2

from skcvideo.colors import WHITE


DEFAULT_FONT = cv2.FONT_HERSHEY_SIMPLEX



def put_text(img, text, org, fontFace=DEFAULT_FONT, fontScale=1.0, color=WHITE,
        thickness=1, lineType=cv2.LINE_AA, align_x='center', align_y='center'):
    x, y = org
    (w, h), _ = cv2.getTextSize(text, fontFace, fontScale, thickness)

    if align_x == 'left':
        org_x = x
    elif align_x == 'center':
        org_x = x - w // 2
    elif align_x == 'right':
        org_x = x - w

    if align_y == 'bottom':
        org_y = y
    elif align_y == 'center':
        org_y = y + h // 2
    elif align_y == 'top':
        org_y = y + h

    cv2.putText(
        img=img,
        text=text,
        org=(org_x, org_y),
        fontFace=fontFace,
        fontScale=fontScale,
        color=color,
        thickness=thickness,
        lineType=lineType,
    )



from setuptools import setup


setup(
    name='skcvideo',
    version='0.1.4',
    description='video utils',
    author='SkillCorner',
    author_email='timothe.collet@skillcorner.com',
    license='MIT',
    packages=[
        'skcvideo',
    ],
    install_requires=[
        'click>=7.1.2',
        'numpy>=1.18.5',
        'opencv-python>=4.4.0.46',
        'imageio>=2.9.0',
        'imageio-ffmpeg>=0.4.2',
    ])
